# PageAccessGroupDtoSort


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**empty** | **bool** |  | [optional] 
**sorted** | **bool** |  | [optional] 
**unsorted** | **bool** |  | [optional] 

## Example

```python
from src.client.generated.models.page_access_group_dto_sort import PageAccessGroupDtoSort

# TODO update the JSON string below
json = "{}"
# create an instance of PageAccessGroupDtoSort from a JSON string
page_access_group_dto_sort_instance = PageAccessGroupDtoSort.from_json(json)
# print the JSON string representation of the object
print(PageAccessGroupDtoSort.to_json())

# convert the object into a dict
page_access_group_dto_sort_dict = page_access_group_dto_sort_instance.to_dict()
# create an instance of PageAccessGroupDtoSort from a dict
page_access_group_dto_sort_from_dict = PageAccessGroupDtoSort.from_dict(page_access_group_dto_sort_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


